BFGraph: Minimizer Class Reference

BFGraph

Public Member Functions | Static Public Member Functions | Static Public Attributes
Minimizer Class Reference

## Public Member Functions
| Minimizer (const Minimizer &o)
| Minimizer (const char *s)
Minimizer & | operator= (const Minimizer &o)
void | set_empty ()
void | set_deleted ()
bool | operator< (const Minimizer &o) const
bool | operator== (const Minimizer &o) const
bool | operator!= (const Minimizer &o) const
void | set_minimizer (const char *s)
uint64_t | hash () const
Minimizer | twin () const
Minimizer | rep () const
Minimizer | getLink (const size_t index) const
Minimizer | forwardBase (const char b) const
Minimizer | backwardBase (const char b) const
std::string | getBinary () const
void | toString (char *s) const
std::string | toString () const

## Static Public Member Functions
static void | set_g (unsigned int _g)

## Static Public Attributes
static const unsigned int | MAX_G = 32
static unsigned int | g = 0

The documentation for this class was generated from the following files:

- src/Kmer.hpp
- src/Kmer.cpp